==> eartho_one-1.1.2.tar.gz: README.md <==
<div id="top"></div>
<br />
<div align="center">
  <a href="https://eartho.world">
    <img src="https://user-images.githubusercontent.com/99670283/172473537-5b4005cf-979b-45cf-bc8a-0f74fb6842e5.png" alt="Logo" width="128" height="128">
  </a>

  <h1 align="center">Eartho. One</h1>

  <p align="center">
    One line of code to authenticate users via<br /><b>Any social network, metamask and phone authentication</b><br /><br />
You don't need to read the documents of all companies and you don't need to open accounts there.<br />
We are a third layer that abstracts the complexity for you and protects your users from being tracked.<br /><br />
You can easily keep your backend solution - self server / firebase / amplify , or get a nocode solution from us.<br /><br />
    <a href="https://www.eartho.world/product/learn"><strong>Quick Start »</strong></a>
    <br />
    <br />
    <a href="https://eartho.world">Our Website</a>
    ·
    <a href="https://github.com/eartho-group/one-client-flutter/issues">Report Bug</a>
    ·
    <a href="https://github.com/eartho-group/one-client-flutter/issues">Request Feature</a>
    ·
    <a href="https://discord.gg/5QbuTNTG2q">Discord</a>
  </p>
 <br />
<img src="https://user-images.githubusercontent.com/99670283/177643618-21ef51cd-3ed1-4ed0-a75e-f5cb948a8f13.png">
</div>


<!-- ABOUT THE PROJECT -->

## About The Project

<p align="center">
<br />
    <img src="https://user-images.githubusercontent.com/99670283/173504901-695e423a-de2a-4f70-873b-33fce39aa49c.png" alt="Logo" height="300" />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    <img src="https://user-images.githubusercontent.com/99670283/172473765-7744c0ab-e203-4294-8385-5678e4d9d757.gif" alt="Logo" height="300" />
<br /><br /><br />
Get all integrations at once. No extra steps.
From improving customer experience through seamless sign-on to making auth as easy as a click of a button – your login box must find the right balance between user convenience, privacy and security.


Here's why:

* Ready high converting UI/UX
* Login from Google, Twitter, Github, Facebook, Apple, Microsoft at once with not extra steps or
  extra effort.
* Your users will be protected under our third layer, we prevent from companies to track after your
  users.
* Advanced analytics and info about your app from all sources. ready for use. no extra steps
* No-Code / Your own server. you decide. We support all, your own server, our server, firebase auth
  and many more.

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- GETTING STARTED -->

## Getting Started

<h3 align="center">Only 3 simple steps and you done</h3>
<p align="center">

  Develop fast<br />
  Get users from all sources into your app fast!<br />
  One line of code to authenticate users via any social network. Eartho also supports web3 login via Metamask etc.<br />
  You dont need to read the docs of all companies and you dont need to open accounts there. <br />
  
```
  final options = { accessId: "0xd...07" };
  final crendentials = earthoOne.connectWithRedirect(options);  
```
  
We manage our documents on our website as a single source of truth. Open our quick start guide to
get started.

<br /> 
<h3>Full Docs Here<br /> 
<a href="https://www.eartho.world/product/learn"> 
https://www.eartho.world/product/learn
</a></h3>
<br /> <br />
<h3>
<a href="https://discord.gg/5QbuTNTG2q"> 
Our Discord For Live Support
</a></h3>
</p>
<br /> <br />

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- USAGE EXAMPLES -->

## Usage

Check the example folder

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- LICENSE -->

## License

Distributed under the Mozilla Public License Version 2.0. See `LICENSE` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTACT -->

## Contact

Eartho<br />


Discord - [Link](https://discord.gg/5QbuTNTG2q)<br />
Twitter - [@eartho_world](https://twitter.com/eartho_world)<br />
Email - contact@eartho.world<br />

Project Link: [https://github.com/eartho-group/](https://github.com/eartho-group/)

<p align="right">(<a href="#top">back to top</a>)</p>

==> eartho_one-1.1.3.tar.gz: README.md <==
<div id="top"></div>
<br />
<div align="center">
  <a href="https://eartho.world">
    <img src="https://user-images.githubusercontent.com/99670283/172473537-5b4005cf-979b-45cf-bc8a-0f74fb6842e5.png" alt="Logo" width="128" height="128">
  </a>

  <h1 align="center">Eartho. One</h1>

  <p align="center">
    One line of code to authenticate users via<br /><b>Any social network, metamask and phone authentication</b><br /><br />
You don't need to read the documents of all companies and you don't need to open accounts there.<br />
We are a third layer that abstracts the complexity for you and protects your users from being tracked.<br /><br />
You can easily keep your backend solution - self server / firebase / amplify , or get a nocode solution from us.<br /><br />
    <a href="https://www.eartho.world/product/learn"><strong>Quick Start »</strong></a>
    <br />
    <br />
    <a href="https://eartho.world">Our Website</a>
    ·
    <a href="https://github.com/eartho-group/one-client-flutter/issues">Report Bug</a>
    ·
    <a href="https://github.com/eartho-group/one-client-flutter/issues">Request Feature</a>
    ·
    <a href="https://discord.gg/5QbuTNTG2q">Discord</a>
  </p>
 <br />
<img src="https://user-images.githubusercontent.com/99670283/177643618-21ef51cd-3ed1-4ed0-a75e-f5cb948a8f13.png">
</div>


<!-- ABOUT THE PROJECT -->

## About The Project

<p align="center">
<br />
    <img src="https://user-images.githubusercontent.com/99670283/173504901-695e423a-de2a-4f70-873b-33fce39aa49c.png" alt="Logo" height="300" />&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
    <img src="https://user-images.githubusercontent.com/99670283/178576414-ac74ae1f-c072-4ea2-81e4-a0b758d5256d.gif" alt="Logo" height="300" />
<br /><br /><br />
Get all integrations at once. No extra steps.
From improving customer experience through seamless sign-on to making auth as easy as a click of a button – your login box must find the right balance between user convenience, privacy and security.


Here's why:

* Ready high converting UI/UX
* Login from Google, Twitter, Github, Facebook, Apple, Microsoft at once with not extra steps or
  extra effort.
* Your users will be protected under our third layer, we prevent from companies to track after your
  users.
* Advanced analytics and info about your app from all sources. ready for use. no extra steps
* No-Code / Your own server. you decide. We support all, your own server, our server, firebase auth
  and many more.

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- GETTING STARTED -->

## Getting Started

<h3 align="center">Only 3 simple steps and you done</h3>
<p align="center">

  Develop fast<br />
  Get users from all sources into your app fast!<br />
  One line of code to authenticate users via any social network. Eartho also supports web3 login via Metamask etc.<br />
  You dont need to read the docs of all companies and you dont need to open accounts there. <br />
  
```
  final options = { accessId: "0xd...07" };
  final crendentials = earthoOne.connectWithRedirect(options);  
```
  
We manage our documents on our website as a single source of truth. Open our quick start guide to
get started.

<br /> 
<h3>Full Docs Here<br /> 
<a href="https://www.eartho.world/product/learn"> 
https://www.eartho.world/product/learn
</a></h3>
<br /> <br />
<h3>
<a href="https://discord.gg/5QbuTNTG2q"> 
Our Discord For Live Support
</a></h3>
</p>
<br /> <br />

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- USAGE EXAMPLES -->

## Usage

Check the example folder

<p align="right">(<a href="#top">back to top</a>)</p>


<!-- LICENSE -->

## License

Distributed under the Mozilla Public License Version 2.0. See `LICENSE` for more information.

<p align="right">(<a href="#top">back to top</a>)</p>



<!-- CONTACT -->

## Contact

Eartho<br />


Discord - [Link](https://discord.gg/5QbuTNTG2q)<br />
Twitter - [@eartho_world](https://twitter.com/eartho_world)<br />
Email - contact@eartho.world<br />

Project Link: [https://github.com/eartho-group/](https://github.com/eartho-group/)

<p align="right">(<a href="#top">back to top</a>)</p>
